@@ -3,13 +3,13 @@ from gettext import gettext as _
 from deskbar.core.Utils import url_show_file
 from os.path import exists
 import gnomevfs
+import logging
+
+LOGGER = logging.getLogger(__name__) 
 
 class OpenFileAction(deskbar.interfaces.Action):
     """
     Open file with its preferred application
-    
-    This class does *not* take into account whether
-    a preferred application is registered for the file
     """
     
     def __init__(self, name, url, escape=True):
@@ -29,7 +29,20 @@ class OpenFileAction(deskbar.interfaces.Action):
         url = self._url[7:]
         if not self._escape:
             url = gnomevfs.unescape_string_for_display(url)
-        return exists( url )
+
+        if not exists(url):
+            LOGGER.debug("File %s does not exist" % url)
+            return False
+        else:
+            try:
+                mime_type = gnomevfs.get_mime_type(url)
+                returnval = gnomevfs.mime_get_default_application(mime_type) != None
+            except RuntimeError, e:
+                # get_mime_type throws a RuntimeException when something went wrong
+                returnval = False
+        if not returnval:
+            LOGGER.debug("File %s has no default application" % url)
+        return returnval
     
     def get_hash(self):
         return self._url
@@ -38,4 +51,4 @@ class OpenFileAction(deskbar.interfaces.Action):
         return _("Open %s") % "<b>%(name)s</b>"
     
     def activate(self, text=None):
-        url_show_file(self._url, escape=self._escape)
\ No newline at end of file
+        url_show_file(self._url, escape=self._escape)
